@@ -1,6 +1,12 @@
 #' Calculate Yearly Means for Event Metrics.
 #'
 #' @param data Accepts the data returned by the \code{\link{detect}} function.
+#' @param x This column is expected to contain a vector of dates as per the
+#' specification of \code{make_whole}. If a column headed \code{t} is present in
+#' the dataframe, this argument may be ommitted; otherwise, specify the name of
+#' the column with dates here.
+#' @param y This is a column containing the measurement variable. If the column
+#' name differs from the default (i.e. \code{temp}), specify the name here.
 #' @param report Specify either \code{full} or \code{partial}. Selecting \code{full} causes
 #' the report to contain NAs for any years in which no events were detected
 #' (except for \code{count}, which will be zero in those years), while \code{partial}
@@ -62,8 +68,9 @@
 #' @export
 #'
 #' @examples
-#' # t_dat <- make_whole(sst_Med)
-#' # res <- detect(t_dat, climatology_start = 1983, climatology_end = 2012) # using default values
+#' # ts_dat <- make_whole(sst_Med)
+#' # res <- detect(ts_dat, climatology_start = "1983-01-01",
+#' #               climatology_end = "2012-12-31")
 #' # out <- block_average(res)
 #' # summary(glm(count ~ year, out, family = "poisson"))
 #'
@@ -74,14 +81,23 @@
 #' }
 block_average <-
   function(data,
+           x = t,
+           y = temp,
            report = "full") {
 
+    quo_x <- rlang::enquo(x)
+    quo_y <- rlang::enquo(y)
+
+    clim <- data$clim %>%
+      dplyr::rename(t = !!quo_x,
+                    temp = !!quo_y)
+
     year <- temp <- date_start <- temp_mean <- temp_min <- temp_max <- NULL ###
-    temp_yr <- data$clim %>%
-      dplyr::group_by(year = lubridate::year(date)) %>%
+    temp_yr <- clim %>%
+      dplyr::group_by(year = lubridate::year(t)) %>%
       dplyr::summarise(temp_mean = mean(temp, na.rm = TRUE),
-                temp_min = min(temp),
-                temp_max = max(temp))
+                       temp_min = min(temp),
+                       temp_max = max(temp))
 
     duration <- count <- int_mean <- int_max <- int_var <- int_cum <-
       int_mean_rel_thresh <- int_max_rel_thresh <- int_var_rel_thresh <-
@@ -91,30 +107,30 @@ block_average <-
     event_block <- data$event %>%
       dplyr::group_by(year = lubridate::year(date_start)) %>%
       dplyr::summarise(count = length(duration),
-                int_mean = mean(int_mean),
-                int_max = mean(int_max),
-                int_var = mean(int_var),
-                int_cum = mean(int_cum),
-                int_mean_rel_thresh = mean(int_mean_rel_thresh),
-                int_max_rel_thresh = mean(int_max_rel_thresh),
-                int_var_rel_thresh = mean(int_var_rel_thresh),
-                int_cum_rel_thresh = mean(int_cum_rel_thresh),
-                int_mean_abs = mean(int_mean_abs),
-                int_max_abs = mean(int_max_abs),
-                int_var_abs = mean(int_var_abs),
-                int_cum_abs = mean(int_cum_abs),
-                int_mean_norm = mean(int_mean_norm),
-                int_max_norm = mean(int_max_norm),
-                rate_onset = mean(rate_onset),
-                rate_decline = mean(rate_decline),
-                total_days = sum(duration),
-                total_icum = sum(int_cum))
+                       int_mean = mean(int_mean),
+                       int_max = mean(int_max),
+                       int_var = mean(int_var),
+                       int_cum = mean(int_cum),
+                       int_mean_rel_thresh = mean(int_mean_rel_thresh),
+                       int_max_rel_thresh = mean(int_max_rel_thresh),
+                       int_var_rel_thresh = mean(int_var_rel_thresh),
+                       int_cum_rel_thresh = mean(int_cum_rel_thresh),
+                       int_mean_abs = mean(int_mean_abs),
+                       int_max_abs = mean(int_max_abs),
+                       int_var_abs = mean(int_var_abs),
+                       int_cum_abs = mean(int_cum_abs),
+                       int_mean_norm = mean(int_mean_norm),
+                       int_max_norm = mean(int_max_norm),
+                       rate_onset = mean(rate_onset),
+                       rate_decline = mean(rate_decline),
+                       total_days = sum(duration),
+                       total_icum = sum(int_cum))
 
     if (report == "full") {
       event_block <- dplyr::left_join(temp_yr, event_block, by = "year")
     } else if (report == "partial") {
       event_block <-
-      dplyr::inner_join(temp_yr, event_block, by = "year")
+        dplyr::inner_join(temp_yr, event_block, by = "year")
     } else stop("Oops, 'report' must be either 'full' or 'partial'!")
 
     event_block$count[is.na(event_block$count)] <- 0
